cljs-http.core


abort!cljs

(abort! channel)

Attempt to close the given channel and abort the pending HTTP request with which it is associated.

Attempt to close the given channel and abort the pending HTTP request
with which it is associated.
sourceraw docstring

apply-default-headers!cljs

(apply-default-headers! xhr headers)

Takes an XhrIo object and applies the default-headers to it.

Takes an XhrIo object and applies the default-headers to it.
sourceraw docstring

apply-response-type!cljs

(apply-response-type! xhr response-type)

Takes an XhrIo object and sets response-type if not nil.

Takes an XhrIo object and sets response-type if not nil.
sourceraw docstring

build-xhrcljs

(build-xhr {:keys [with-credentials? default-headers response-type]
            :as request})

Builds an XhrIo object from the request parameters.

Builds an XhrIo object from the request parameters.
sourceraw docstring

error-kwcljs

source

jsonpcljs

(jsonp {:keys [timeout callback-name cancel keywordize-keys?]
        :or {keywordize-keys? true}
        :as request})

Execute the JSONP request corresponding to the given Ring request map and return a core.async channel.

Execute the JSONP request corresponding to the given Ring request
map and return a core.async channel.
sourceraw docstring

pending-requestscljs

source

requestcljs

(request {:keys [request-method] :as request})

Execute the HTTP request corresponding to the given Ring request map and return a core.async channel.

Execute the HTTP request corresponding to the given Ring request
map and return a core.async channel.
sourceraw docstring

xhrcljs

(xhr {:keys [request-method headers body with-credentials? cancel progress]
      :as request})

Execute the HTTP request corresponding to the given Ring request map and return a core.async channel.

Execute the HTTP request corresponding to the given Ring request
map and return a core.async channel.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries