(android?)Returns true if the user agent is an Android client.
Returns true if the user agent is an Android client.
(basic-auth credentials)Returns the value of the HTTP basic authentication header for
credentials.
Returns the value of the HTTP basic authentication header for `credentials`.
(build-headers m)Build the headers from the map.
Build the headers from the map.
(build-url {:keys [scheme server-name server-port uri query-string]})Build the url from the request map.
Build the url from the request map.
(camelize s)Returns dash separated string s in camel case.
Returns dash separated string `s` in camel case.
(json-decode s)JSON decode an object from s.
JSON decode an object from `s`.
(json-encode x)JSON encode x into a String.
JSON encode `x` into a String.
(transit-decode s type opts)Transit decode an object from s.
Transit decode an object from `s`.
(transit-encode x type opts)Transit encode x into a String.
Transit encode `x` into a String.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |